pub enum OptionValue {
On,
Off,
Unknown,
}Expand description
Tri-state option value used when modeling zsh option state.
Variants
On
The option is enabled.
Off
The option is disabled.
Unknown
The option value is unknown or differs across merged states.
Implementations
Sourceimpl OptionValue
impl OptionValue
Sourcepub const fn is_definitely_on(self) -> bool
pub const fn is_definitely_on(self) -> bool
Returns true when the option is known to be enabled.
Sourcepub const fn is_definitely_off(self) -> bool
pub const fn is_definitely_off(self) -> bool
Returns true when the option is known to be disabled.