pub struct LexedWord<'a> { /* private fields */ }Expand description
Source-backed representation of a shell word produced by the lexer.
Implementations
Sourceimpl<'a> LexedWord<'a>
impl<'a> LexedWord<'a>
Sourcepub fn segments(&self) -> impl Iterator<Item = &LexedWordSegment<'a>>
pub fn segments(&self) -> impl Iterator<Item = &LexedWordSegment<'a>>
Iterate over the segments that make up this word.
Sourcepub fn text(&self) -> Option<&str>
pub fn text(&self) -> Option<&str>
Return the word text when it is represented by a single segment.
Sourcepub fn joined_text(&self) -> String
pub fn joined_text(&self) -> String
Join all segments into an owned string.
Sourcepub fn single_segment(&self) -> Option<&LexedWordSegment<'a>>
pub fn single_segment(&self) -> Option<&LexedWordSegment<'a>>
Return the only segment when this word is not segmented.