LexedWordSegment

Struct LexedWordSegment 

pub struct LexedWordSegment<'a> { /* private fields */ }
One segment of a lexed shell word, optionally backed by source text.

Implementations

Source

impl<'a> LexedWordSegment<'a>

pub fn as_str(&self) -> &str

Borrow this segment’s cooked text.

pub const fn kind(&self) -> LexedWordSegmentKind

Return the lexical classification of this segment.

pub const fn span(&self) -> Option<Span>

Return the span of the inner text, if it is tracked.

pub fn wrapper_span(&self) -> Option<Span>

Return the span including surrounding quoting syntax when available.