pub struct ZshCaseGroupPart {
pub pattern_part_index: usize,
pub span: Span,
}Expand description
One branch separator recognized inside a zsh case pattern group.
Fields
pattern_part_index: usizeIndex of the owning pattern part within the parsed pattern.
span: SpanSource span covering the separator syntax.