pub struct LexedToken<'a> {
pub kind: TokenKind,
pub span: Span,
/* private fields */
}Expand description
Token produced by the shell lexer.
Fields
kind: TokenKindToken kind used by the parser.
span: SpanSource span covered by the token.
Implementations
Sourceimpl<'a> LexedToken<'a>
impl<'a> LexedToken<'a>
Sourcepub fn word_text(&self) -> Option<&str>
pub fn word_text(&self) -> Option<&str>
Borrow the token text when it is a single-segment word token.
Sourcepub fn word_string(&self) -> Option<String>
pub fn word_string(&self) -> Option<String>
Return an owned string containing the token’s word text.
Sourcepub fn word(&self) -> Option<&LexedWord<'a>>
pub fn word(&self) -> Option<&LexedWord<'a>>
Borrow the structured word payload for word-like tokens.
Sourcepub fn source_slice<'b>(&self, source: &'b str) -> Option<&'b str>
pub fn source_slice<'b>(&self, source: &'b str) -> Option<&'b str>
Borrow the original source slice when the token is source-backed and uncooked.
Sourcepub fn fd_value(&self) -> Option<i32>
pub fn fd_value(&self) -> Option<i32>
Return the file-descriptor payload for redirection tokens that carry one.
Sourcepub fn fd_pair_value(&self) -> Option<(i32, i32)>
pub fn fd_pair_value(&self) -> Option<(i32, i32)>
Return the (source_fd, target_fd) payload for descriptor-pair redirections.
Sourcepub fn error_kind(&self) -> Option<LexerErrorKind>
pub fn error_kind(&self) -> Option<LexerErrorKind>
Return the lexer error payload when this token represents TokenKind::Error.