pub struct LexedWordSegment<'a> { /* private fields */ }Expand description
One segment of a lexed shell word, optionally backed by source text.
Implementations
Sourceimpl<'a> LexedWordSegment<'a>
impl<'a> LexedWordSegment<'a>
Sourcepub const fn kind(&self) -> LexedWordSegmentKind
pub const fn kind(&self) -> LexedWordSegmentKind
Return the lexical classification of this segment.
Sourcepub fn wrapper_span(&self) -> Option<Span>
pub fn wrapper_span(&self) -> Option<Span>
Return the span including surrounding quoting syntax when available.