pub struct ShellProfile {
pub dialect: ShellDialect,
pub options: Option<ZshOptionState>,
}Expand description
Dialect plus optional zsh option state used to configure the lexer and parser.
Fields
dialect: ShellDialectShell dialect to parse.
options: Option<ZshOptionState>Optional zsh option state, used only for zsh parsing.
Implementations
Sourceimpl ShellProfile
impl ShellProfile
Sourcepub fn native(dialect: ShellDialect) -> Self
pub fn native(dialect: ShellDialect) -> Self
Build a native profile for dialect.
Sourcepub fn with_zsh_options(dialect: ShellDialect, options: ZshOptionState) -> Self
pub fn with_zsh_options(dialect: ShellDialect, options: ZshOptionState) -> Self
Build a profile with explicit zsh option state.
Sourcepub fn zsh_options(&self) -> Option<&ZshOptionState>
pub fn zsh_options(&self) -> Option<&ZshOptionState>
Borrow the zsh option state, if this profile carries one.