ShellProfile

Struct ShellProfile 

pub struct ShellProfile {
    pub dialect: ShellDialect,
    pub options: Option<ZshOptionState>,
}
Dialect plus optional zsh option state used to configure the lexer and parser.

Fields

dialect: ShellDialect

Shell dialect to parse.

options: Option<ZshOptionState>

Optional zsh option state, used only for zsh parsing.

Implementations

Source

impl ShellProfile

pub fn native(dialect: ShellDialect) -> Self

Build a native profile for dialect.

pub fn with_zsh_options(dialect: ShellDialect, options: ZshOptionState) -> Self

Build a profile with explicit zsh option state.

pub fn zsh_options(&self) -> Option<&ZshOptionState>

Borrow the zsh option state, if this profile carries one.