ZshOptionState

Struct ZshOptionState 

pub struct ZshOptionState {
Show 27 fields pub sh_word_split: OptionValue, pub glob_subst: OptionValue, pub rc_expand_param: OptionValue, pub glob: OptionValue, pub nomatch: OptionValue, pub null_glob: OptionValue, pub csh_null_glob: OptionValue, pub extended_glob: OptionValue, pub ksh_glob: OptionValue, pub sh_glob: OptionValue, pub bare_glob_qual: OptionValue, pub glob_dots: OptionValue, pub equals: OptionValue, pub magic_equal_subst: OptionValue, pub sh_file_expansion: OptionValue, pub glob_assign: OptionValue, pub ignore_braces: OptionValue, pub ignore_close_braces: OptionValue, pub brace_ccl: OptionValue, pub ksh_arrays: OptionValue, pub ksh_zero_subscript: OptionValue, pub short_loops: OptionValue, pub short_repeat: OptionValue, pub rc_quotes: OptionValue, pub interactive_comments: OptionValue, pub c_bases: OptionValue, pub octal_zeroes: OptionValue,
}
Snapshot of zsh option state used by the parser and lexer.

Fields

sh_word_split: OptionValue

State of the sh_word_split option.

glob_subst: OptionValue

State of the glob_subst option.

rc_expand_param: OptionValue

State of the rc_expand_param option.

glob: OptionValue

State of the glob option.

nomatch: OptionValue

State of the nomatch option.

null_glob: OptionValue

State of the null_glob option.

csh_null_glob: OptionValue

State of the csh_null_glob option.

extended_glob: OptionValue

State of the extended_glob option.

ksh_glob: OptionValue

State of the ksh_glob option.

sh_glob: OptionValue

State of the sh_glob option.

bare_glob_qual: OptionValue

State of the bare_glob_qual option.

glob_dots: OptionValue

State of the glob_dots option.

equals: OptionValue

State of the equals option.

magic_equal_subst: OptionValue

State of the magic_equal_subst option.

sh_file_expansion: OptionValue

State of the sh_file_expansion option.

glob_assign: OptionValue

State of the glob_assign option.

ignore_braces: OptionValue

State of the ignore_braces option.

ignore_close_braces: OptionValue

State of the ignore_close_braces option.

brace_ccl: OptionValue

State of the brace_ccl option.

ksh_arrays: OptionValue

State of the ksh_arrays option.

ksh_zero_subscript: OptionValue

State of the ksh_zero_subscript option.

short_loops: OptionValue

State of the short_loops option.

short_repeat: OptionValue

State of the short_repeat option.

rc_quotes: OptionValue

State of the rc_quotes option.

interactive_comments: OptionValue

State of the interactive_comments option.

c_bases: OptionValue

State of the c_bases option.

octal_zeroes: OptionValue

State of the octal_zeroes option.

Implementations

Source

impl ZshOptionState

pub const fn zsh_default() -> Self

Default zsh option state used for native zsh parsing.

pub fn for_emulate(mode: ZshEmulationMode) -> Self

Option state implied by emulate <mode>.

pub fn apply_setopt(&mut self, name: &str) -> bool

Apply a zsh setopt-style option name.

Returns true when the option name was recognized.

pub fn apply_unsetopt(&mut self, name: &str) -> bool

Apply a zsh unsetopt-style option name.

Returns true when the option name was recognized.

pub fn merge(&self, other: &Self) -> Self

Merge two option snapshots field by field.