pub struct ZshOptionState {Show 27 fields
pub sh_word_split: OptionValue,
pub glob_subst: OptionValue,
pub rc_expand_param: OptionValue,
pub glob: OptionValue,
pub nomatch: OptionValue,
pub null_glob: OptionValue,
pub csh_null_glob: OptionValue,
pub extended_glob: OptionValue,
pub ksh_glob: OptionValue,
pub sh_glob: OptionValue,
pub bare_glob_qual: OptionValue,
pub glob_dots: OptionValue,
pub equals: OptionValue,
pub magic_equal_subst: OptionValue,
pub sh_file_expansion: OptionValue,
pub glob_assign: OptionValue,
pub ignore_braces: OptionValue,
pub ignore_close_braces: OptionValue,
pub brace_ccl: OptionValue,
pub ksh_arrays: OptionValue,
pub ksh_zero_subscript: OptionValue,
pub short_loops: OptionValue,
pub short_repeat: OptionValue,
pub rc_quotes: OptionValue,
pub interactive_comments: OptionValue,
pub c_bases: OptionValue,
pub octal_zeroes: OptionValue,
}Expand description
Snapshot of zsh option state used by the parser and lexer.
Fields
sh_word_split: OptionValueState of the sh_word_split option.
glob_subst: OptionValueState of the glob_subst option.
rc_expand_param: OptionValueState of the rc_expand_param option.
glob: OptionValueState of the glob option.
nomatch: OptionValueState of the nomatch option.
null_glob: OptionValueState of the null_glob option.
csh_null_glob: OptionValueState of the csh_null_glob option.
extended_glob: OptionValueState of the extended_glob option.
ksh_glob: OptionValueState of the ksh_glob option.
sh_glob: OptionValueState of the sh_glob option.
bare_glob_qual: OptionValueState of the bare_glob_qual option.
glob_dots: OptionValueState of the glob_dots option.
equals: OptionValueState of the equals option.
magic_equal_subst: OptionValueState of the magic_equal_subst option.
sh_file_expansion: OptionValueState of the sh_file_expansion option.
glob_assign: OptionValueState of the glob_assign option.
ignore_braces: OptionValueState of the ignore_braces option.
ignore_close_braces: OptionValueState of the ignore_close_braces option.
brace_ccl: OptionValueState of the brace_ccl option.
ksh_arrays: OptionValueState of the ksh_arrays option.
ksh_zero_subscript: OptionValueState of the ksh_zero_subscript option.
short_loops: OptionValueState of the short_loops option.
short_repeat: OptionValueState of the short_repeat option.
rc_quotes: OptionValueState of the rc_quotes option.
interactive_comments: OptionValueState of the interactive_comments option.
c_bases: OptionValueState of the c_bases option.
octal_zeroes: OptionValueState of the octal_zeroes option.
Implementations
Sourceimpl ZshOptionState
impl ZshOptionState
Sourcepub const fn zsh_default() -> Self
pub const fn zsh_default() -> Self
Default zsh option state used for native zsh parsing.
Sourcepub fn for_emulate(mode: ZshEmulationMode) -> Self
pub fn for_emulate(mode: ZshEmulationMode) -> Self
Option state implied by emulate <mode>.
Sourcepub fn apply_setopt(&mut self, name: &str) -> bool
pub fn apply_setopt(&mut self, name: &str) -> bool
Apply a zsh setopt-style option name.
Returns true when the option name was recognized.
Sourcepub fn apply_unsetopt(&mut self, name: &str) -> bool
pub fn apply_unsetopt(&mut self, name: &str) -> bool
Apply a zsh unsetopt-style option name.
Returns true when the option name was recognized.